Documentation
¶
Overview ¶
Package sync coordinates synchronization of Okta groups to GitHub teams. depends only on domain interfaces, not concrete client implementations.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Syncer ¶
type Syncer struct {
// contains filtered or unexported fields
}
Syncer coordinates synchronization of Okta groups to GitHub teams.
func NewSyncer ¶
func NewSyncer(oktaClient domain.OktaClient, githubClient domain.GitHubClient, rules []domain.SyncRule, safetyThreshold float64, logger *slog.Logger) *Syncer
NewSyncer creates a new Okta to GitHub syncer.
func (*Syncer) DetectOrphanedUsers ¶
func (s *Syncer) DetectOrphanedUsers(ctx context.Context, syncedTeams []string) (*domain.OrphanedUsersReport, error)
DetectOrphanedUsers finds organization members not in any synced teams. excludes external collaborators.
Click to show internal directories.
Click to hide internal directories.